==> pdf-model-arlington-1.29.14-sources.jar: org/verapdf/model/alayer/AActionSubmitForm.java <==
/**
 * This file is part of VeraPDF Validation Model API for Arlington PDF Model, a module of the veraPDF project.
 * Copyright (c) 2015-2025, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * VeraPDF Validation Model API for Arlington PDF Model is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with VeraPDF Validation Model API for Arlington PDF Model as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * VeraPDF Validation Model API for Arlington PDF Model as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AActionSubmitForm extends AObject {
	



	/**
	*/
	public Boolean getcontainsCharSet();

	/**
	*/
	public String getCharSetType();

	/**
	*/
	public Boolean getCharSetHasTypeString();

	/**
	*/
	public String getCharSetStringValue();

	/**
	*/
	public Boolean getcontainsF();

	/**
	*/
	public String getFType();

	/**
	*/
	public Boolean getFHasTypeDictionary();

	/**
	*/
	public Boolean getFHasTypeString();

	/**
	*/
	public Boolean getcontainsFields();

	/**
	*/
	public String getFieldsType();

	/**
	*/
	public Boolean getFieldsHasTypeArray();

	/**
	*/
	public Boolean getcontainsFlags();

	/**
	*/
	public String getFlagsType();

	/**
	*/
	public Boolean getFlagsHasTypeBitmask();

	/**
	*/
	public Long getFlagsBitmaskValue();

	/**
	*/
	public Boolean getcontainsS();

	/**
	*/
	public String getSType();

	/**
	*/
	public Boolean getSHasTypeName();

	/**
	*/
	public String getSNameValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();
}

==> pdf-model-arlington-1.29.16-sources.jar: org/verapdf/model/alayer/AActionSubmitForm.java <==
/**
 * This file is part of VeraPDF Validation Model API for Arlington PDF Model, a module of the veraPDF project.
 * Copyright (c) 2015-2025, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * VeraPDF Validation Model API for Arlington PDF Model is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with VeraPDF Validation Model API for Arlington PDF Model as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * VeraPDF Validation Model API for Arlington PDF Model as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AActionSubmitForm extends AObject {
	




	/**
	*/
	public Boolean getcontainsCharSet();

	/**
	*/
	public String getCharSetType();

	/**
	*/
	public Boolean getCharSetHasTypeString();

	/**
	*/
	public String getCharSetStringValue();

	/**
	*/
	public Boolean getcontainsF();

	/**
	*/
	public String getFType();

	/**
	*/
	public Boolean getFHasTypeDictionary();

	/**
	*/
	public Boolean getFHasTypeString();

	/**
	*/
	public Boolean getcontainsFields();

	/**
	*/
	public String getFieldsType();

	/**
	*/
	public Boolean getFieldsHasTypeArray();

	/**
	*/
	public Boolean getcontainsFlags();

	/**
	*/
	public String getFlagsType();

	/**
	*/
	public Boolean getFlagsHasTypeBitmask();

	/**
	*/
	public Long getFlagsBitmaskValue();

	/**
	*/
	public Boolean getcontainsNext();

	/**
	*/
	public String getNextType();

	/**
	*/
	public Boolean getNextHasTypeArray();

	/**
	*/
	public Boolean getNextHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsS();

	/**
	*/
	public String getSType();

	/**
	*/
	public Boolean getSHasTypeName();

	/**
	*/
	public String getSNameValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();
}
